@@ -3,9 +3,9 @@ package Sah::Schema::hexstr;
 use strict;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-06-08'; # DATE
+our $DATE = '2022-06-09'; # DATE
 our $DIST = 'Sah-Schemas-Str'; # DIST
-our $VERSION = '0.007'; # VERSION
+our $VERSION = '0.008'; # VERSION
 
 our $schema = [str => {
     summary => 'String of bytes in hexadecimal',
@@ -37,7 +37,7 @@ Sah::Schema::hexstr - String of bytes in hexadecimal
 
 =head1 VERSION
 
-This document describes version 0.007 of Sah::Schema::hexstr (from Perl distribution Sah-Schemas-Str), released on 2022-06-08.
+This document describes version 0.008 of Sah::Schema::hexstr (from Perl distribution Sah-Schemas-Str), released on 2022-06-09.
 
 =head1 SYNOPSIS
 
@@ -71,7 +71,7 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data);
  
  # a sample valid data
- $data = "";
+ $data = "a0";
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
@@ -86,8 +86,8 @@ prefiltered) value:
  my $res = $validator->($data); # [$errmsg, $validated_val]
  
  # a sample valid data
- $data = "";
- my $res = $validator->($data); # => ["",""]
+ $data = "a0";
+ my $res = $validator->($data); # => ["","a0"]
  
  # a sample invalid data
  $data = "a0f";
