@@ -3,9 +3,9 @@ package Sah::Schema::str_or_re;
 use strict;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-06-08'; # DATE
+our $DATE = '2022-06-09'; # DATE
 our $DIST = 'Sah-Schemas-Str'; # DIST
-our $VERSION = '0.007'; # VERSION
+our $VERSION = '0.008'; # VERSION
 
 our $schema = [any => {
     summary => 'String or regex (if string is of the form `/.../`)',
@@ -13,9 +13,14 @@ our $schema = [any => {
 
 Either string or Regexp object is accepted.
 
-If string is of the form of `/.../`, then it will be compiled into a Regexp
-object. Currently modifiers `i`, `m`, and `s` after the second `/` are allowed.
-If the regex pattern inside `/.../` is invalid, value will be rejected.
+If string is of the form of `/.../` or `qr(...)`, then it will be compiled into
+a Regexp object. If the regex pattern inside `/.../` or `qr(...)` is invalid,
+value will be rejected.
+
+Currently, unlike in normal Perl, for the `qr(...)` form, only parentheses `(`
+and `)` are allowed as the delimiter.
+
+Currently modifiers `i`, `m`, and `s` after the second `/` are allowed.
 
 _
     of => [
@@ -32,8 +37,15 @@ _
 
         {value=>'//', valid=>1, validated_value=>qr//},
         {value=>'/foo', valid=>1, summary=>'Becomes a string'},
+        {value=>'qr(foo', valid=>1, summary=>'Becomes a string'},
+        {value=>'qr(foo(', valid=>1, summary=>'Becomes a string'},
+        {value=>'qr/foo/', valid=>1, summary=>'Becomes a string'},
+
         {value=>'/foo.*/', valid=>1, validated_value=>qr/foo.*/},
+        {value=>'qr(foo.*)', valid=>1, validated_value=>qr/foo.*/},
         {value=>'/foo/is', valid=>1, validated_value=>qr/foo/is},
+        {value=>'qr(foo)is', valid=>1, validated_value=>qr/foo/is},
+
         {value=>'/foo[/', valid=>0, summary=>'Invalid regex'},
     ],
 
@@ -54,7 +66,7 @@ Sah::Schema::str_or_re - String or regex (if string is of the form `/.../`)
 
 =head1 VERSION
 
-This document describes version 0.007 of Sah::Schema::str_or_re (from Perl distribution Sah-Schemas-Str), released on 2022-06-08.
+This document describes version 0.008 of Sah::Schema::str_or_re (from Perl distribution Sah-Schemas-Str), released on 2022-06-09.
 
 =head1 SYNOPSIS
 
@@ -70,10 +82,20 @@ This document describes version 0.007 of Sah::Schema::str_or_re (from Perl distr
 
  "/foo"  # valid (Becomes a string)
 
+ "qr(foo"  # valid (Becomes a string)
+
+ "qr(foo("  # valid (Becomes a string)
+
+ "qr/foo/"  # valid (Becomes a string)
+
  "/foo.*/"  # valid, becomes qr(foo.*)
 
+ "qr(foo.*)"  # valid, becomes qr(foo.*)
+
  "/foo/is"  # valid, becomes qr(foo)si
 
+ "qr(foo)is"  # valid, becomes qr(foo)si
+
  "/foo[/"  # INVALID (Invalid regex)
 
 =head2 Using with Data::Sah
@@ -92,12 +114,12 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data);
  
  # a sample valid data
- $data = "/foo.*/";
+ $data = "qr/foo/";
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
- $data = "/foo[/";
- my $errmsg = $validator->($data); # => "Invalid regex: Unmatched [ in regex; marked by <-- HERE in m/foo[ <-- HERE / at (eval 2474) line 1.\n"
+ $data = {};
+ my $errmsg = $validator->($data); # => "Not of type text"
 
 Often a schema has coercion rule or default value, so after validation the
 validated value is different. To return the validated (set-as-default, coerced,
@@ -107,12 +129,12 @@ prefiltered) value:
  my $res = $validator->($data); # [$errmsg, $validated_val]
  
  # a sample valid data
- $data = "/foo.*/";
- my $res = $validator->($data); # => ["",qr(foo.*)]
+ $data = "qr/foo/";
+ my $res = $validator->($data); # => ["","qr/foo/"]
  
  # a sample invalid data
- $data = "/foo[/";
- my $res = $validator->($data); # => ["Invalid regex: Unmatched [ in regex; marked by <-- HERE in m/foo[ <-- HERE / at (eval 2488) line 1.\n","/foo[/"]
+ $data = {};
+ my $res = $validator->($data); # => ["Not of type text",{}]
 
 Data::Sah can also create validator that returns a hash of detailed error
 message. Data::Sah can even create validator that targets other language, like
@@ -179,9 +201,14 @@ L<Perinci::CmdLine> (L<Perinci::CmdLine::Lite>) to create a CLI:
 
 Either string or Regexp object is accepted.
 
-If string is of the form of C</.../>, then it will be compiled into a Regexp
-object. Currently modifiers C<i>, C<m>, and C<s> after the second C</> are allowed.
-If the regex pattern inside C</.../> is invalid, value will be rejected.
+If string is of the form of C</.../> or C<qr(...)>, then it will be compiled into
+a Regexp object. If the regex pattern inside C</.../> or C<qr(...)> is invalid,
+value will be rejected.
+
+Currently, unlike in normal Perl, for the C<qr(...)> form, only parentheses C<(>
+and C<)> are allowed as the delimiter.
+
+Currently modifiers C<i>, C<m>, and C<s> after the second C</> are allowed.
 
 =head1 HOMEPAGE
 
