@@ -3,9 +3,9 @@ package Sah::Schemas::Str;
 use strict;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-06-08'; # DATE
+our $DATE = '2022-06-09'; # DATE
 our $DIST = 'Sah-Schemas-Str'; # DIST
-our $VERSION = '0.007'; # VERSION
+our $VERSION = '0.008'; # VERSION
 
 1;
 # ABSTRACT: Various string schemas
@@ -22,7 +22,7 @@ Sah::Schemas::Str - Various string schemas
 
 =head1 VERSION
 
-This document describes version 0.007 of Sah::Schemas::Str (from Perl distribution Sah-Schemas-Str), released on 2022-06-08.
+This document describes version 0.008 of Sah::Schemas::Str (from Perl distribution Sah-Schemas-Str), released on 2022-06-09.
 
 =head1 SAH SCHEMAS
 
@@ -60,9 +60,14 @@ String or regex (if string is of the form `E<sol>...E<sol>`).
 
 Either string or Regexp object is accepted.
 
-If string is of the form of C</.../>, then it will be compiled into a Regexp
-object. Currently modifiers C<i>, C<m>, and C<s> after the second C</> are allowed.
-If the regex pattern inside C</.../> is invalid, value will be rejected.
+If string is of the form of C</.../> or C<qr(...)>, then it will be compiled into
+a Regexp object. If the regex pattern inside C</.../> or C<qr(...)> is invalid,
+value will be rejected.
+
+Currently, unlike in normal Perl, for the C<qr(...)> form, only parentheses C<(>
+and C<)> are allowed as the delimiter.
+
+Currently modifiers C<i>, C<m>, and C<s> after the second C</> are allowed.
 
 
 =back
